==> nextcloud-16.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/lib/l10n/mk.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Не можам да впишувам во \"config\" директориумот!",
    "Unknown filetype" : "Непознат тип на датотека",
    "Invalid image" : "Невалидна фотографија",
    "today" : "денеска",
    "yesterday" : "вчера",
    "last month" : "минатиот месец",
    "last year" : "минатата година",
    "seconds ago" : "пред секунди",
    "__language_name__" : "македонски",
    "Apps" : "Аппликации",
    "Users" : "Корисници",
    "Unknown user" : "Непознат корисник",
    "%s enter the database username." : "%s внеси го корисничкото име за базата.",
    "%s enter the database name." : "%s внеси го името на базата.",
    "%s you may not use dots in the database name" : "%s не можеш да користиш точки во името на базата",
    "Oracle username and/or password not valid" : "Oracle корисничкото име и/или лозинката не се валидни",
    "PostgreSQL username and/or password not valid" : "PostgreSQL корисничкото име и/или лозинка не се валидни",
    "Set an admin username." : "Постави администраторско корисничко име",
    "Set an admin password." : "Постави администраторска лозинка.",
    "Could not find category \"%s\"" : "Не можам да најдам категорија „%s“",
    "A valid username must be provided" : "Мора да се обезбеди валидно корисничко име ",
    "A valid password must be provided" : "Мора да се обезбеди валидна лозинка",
    "The username is already being used" : "Корисничкото име е веќе во употреба",
    "Application is not enabled" : "Апликацијата не е овозможена",
    "Authentication error" : "Грешка во автентикација",
    "Token expired. Please reload page." : "Жетонот е истечен. Ве молам превчитајте ја страницата.",
    "%s shared »%s« with you" : "%s споделено »%s« со вас"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/lib/l10n/mk.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Не можам да впишувам во \"config\" директориумот!",
    "Unknown filetype" : "Непознат тип на датотека",
    "Invalid image" : "Невалидна фотографија",
    "today" : "денеска",
    "yesterday" : "вчера",
    "last month" : "минатиот месец",
    "last year" : "минатата година",
    "seconds ago" : "пред неколку секунди",
    "__language_name__" : "македонски",
    "Apps" : "Аппликации",
    "Users" : "Корисници",
    "Unknown user" : "Непознат корисник",
    "%s enter the database username." : "%s внеси го корисничкото име за базата.",
    "%s enter the database name." : "%s внеси го името на базата.",
    "%s you may not use dots in the database name" : "%s не можеш да користиш точки во името на базата",
    "Oracle username and/or password not valid" : "Oracle корисничкото име и/или лозинката не се валидни",
    "PostgreSQL username and/or password not valid" : "PostgreSQL корисничкото име и/или лозинка не се валидни",
    "Set an admin username." : "Постави администраторско корисничко име",
    "Set an admin password." : "Постави администраторска лозинка.",
    "Could not find category \"%s\"" : "Не можам да најдам категорија „%s“",
    "A valid username must be provided" : "Мора да се обезбеди валидно корисничко име ",
    "A valid password must be provided" : "Мора да се обезбеди валидна лозинка",
    "The username is already being used" : "Корисничкото име е веќе во употреба",
    "Application is not enabled" : "Апликацијата не е овозможена",
    "Authentication error" : "Грешка во автентикација",
    "Token expired. Please reload page." : "Жетонот е истечен. Ве молам превчитајте ја страницата.",
    "%s shared »%s« with you" : "%s споделено »%s« со вас"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
